<?php 

class Plugin_Framework {

	private static $instance;
	public $data;
	public $buttons;

	public function __construct($buttons='')
	{
		self::$instance =& $this;
		$this->buttons = $buttons;
	}

	public static function &get_instance()
	{
		return self::$instance;
	}

	public function run()
	{
		foreach($this->buttons as $name=>$button)
		{
			$this->add_shortcode($name, $button['tag'], $button['type']);
		}

		if( is_admin())
		{
			add_filter('mce_css', array(&$this, 'plugin_mce_css'));
			add_action('init', array(&$this, 'before_init'));

			/* Add Style & Scripts To WP head */
			add_action('admin_head', array(&$this, 'enqueue_admin'));
		}
		else
		{
			framework_include_controller('shortcodes');
			$shortcode_class = new Shortcodes;
			
			foreach($this->shortcode_list as $_shortcode)
			{
				if(method_exists('Shortcodes', "{$_shortcode['name']}"))
				{
					add_shortcode("{$_shortcode['tag']}", array($shortcode_class, "{$_shortcode['name']}"));
				}
			}


			/* Add Style & Scripts To WP head */
			add_action('wp_head', array(&$this, 'frontend_head'));
			add_action('wp_footer', array(&$this, 'frontend_footer'));
			add_action('wp_enqueue_scripts', array(&$this, 'enqueue_frontend'));
		}
	}

	public function run_popup()
	{
		foreach($this->buttons as $name=>$button)
		{
			$this->set('tag_'.$name, $button['tag']);
			$this->set('type_'.$name, $button['type']);
		}

		$uri = framework_get_request_uri(0);
		if( isset($uri) && $uri != '')
		{
			framework_get_controller($uri, $this->data, 'popup');
		}
	}

	function enqueue_frontend()  
	{
		wp_register_style('shortcodes', PLUGINAPP_URL . 'assets/css/shortcodes.css', array(), '20120208', 'all');
		wp_enqueue_style( 'shortcodes' );
		wp_enqueue_script('phpjs', PLUGINAPP_URL . 'assets/js/php.js');
	}

	function enqueue_admin()
	{
		wp_register_script('phpjs', PLUGINAPP_URL . 'assets/js/php.js', array(), '20121407', 'all');
		wp_enqueue_script( 'phpjs' );
	}

	function frontend_head()
	{
		echo '<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js"></script> <script>WebFontConfig = { google: { families: [] } };var instant_plugin_url = \''.PLUGINAPP_URL.'\';</script>';
	}

	function frontend_footer()
	{
		echo '<script>';
		echo <<<JS
var wf = document.createElement('script'); wf.src = ('https:' == document.location.protocol ? 'https' : 'http') +
    '://ajax.googleapis.com/ajax/libs/webfont/1/webfont.js'; wf.type = 'text/javascript'; wf.id = 'google_webfont';
wf.async = 'true'; var s = document.getElementsByTagName('script')[0];
if(WebFontConfig.google.families.length > 0) { WebFontConfig.google.families = php_js_array_unique(WebFontConfig.google.families); s.parentNode.insertBefore(wf, s); }
JS;
		echo '</script>';
	}

	function plugin_mce_css()
	{
		if ( ! empty( $mce_css ) )
			$mce_css .= ',';

		$mce_css .= PLUGINAPP_URL . 'assets/css/editor.css';
		return $mce_css;
	}

	function before_init()
	{
		if ( current_user_can('edit_posts') &&  current_user_can('edit_pages') )  
		{
			add_filter('mce_external_plugins', array(&$this, 'mce_plugin_list'));
			add_filter('mce_buttons_3', array(&$this, 'register_button'));	
		}
	}

	public function add_shortcode($name, $tag='notag', $type='enclosed')
	{
		$this->buttons[] = $name;
		$this->shortcode_list[] = array('name'=>$name, 'tag'=>$tag);
		$this->add_mce_plugin($name);
		return $this;
	}

	function add_mce_plugin($name)
	{
		$this->plugin_list[$name] = $name; 
		return $this;
	}

	function register_button($buttons)
	{
		foreach($this->buttons as $key=>$value)
		{
			array_push($buttons, $value);	
		}
		return $buttons;
	}

	function mce_plugin_list($plugin_array)
	{
		$plugin_array['mceshortcode'] = PLUGINAPP_URL."assets/js/shortcodes.php";
		return $plugin_array;
	}

	function set($key, $value='')
	{
		if($key != '')
		{
			$this->data[$key] = $value;
			return $this;
		}
	}

	function view($filename, $data='', $return = FALSE)
	{
		$view = PLUGINAPP_VIEWS . $filename.'.php';
		if(file_exists($view))
		{
			if($this->data['gfont'] == TRUE)
			{
				include PLUGINAPP_PATH . 'config/google_fonts.php';
				$this->set('fonts', explode("\n", $google_fonts));
			}

			if($return == FALSE)
			{
				if(! empty($this->data)) extract($this->data);
				echo framework_include_output($view, $data);
			}
			else
			{
				return framework_compress(framework_include_output($view, $data));
			}
		}

		return $this;
	}

}

/* End of file core.php */